@@ -7,7 +7,8 @@ Created on Thu Sep  5 01:58:23 2019
 
 from acccmip6.utilities.c6db import SearchDB
 from acccmip6.utilities.CMIP6_database import CMIP6DB
-from acccmip6.utilities.util import color, _mod_help, _realizations, _get_rlzn_links
+from acccmip6.utilities.util import _get_rlzn_links, _get_skipped_links
+from acccmip6.utilities.util import color, _mod_help, _realizations
 
 def SearchCmip6(**kwargs):
         _var = kwargs.get('variable', None)
@@ -21,6 +22,8 @@ def SearchCmip6(**kwargs):
         year = kwargs.get('year', None)
         module = kwargs.get('module', None)
         rlzn = kwargs.get('rlzn', None)
+        skip = kwargs.get('skip', None)
+        cr = kwargs.get('cr', None)
         
         if (module == 'on'):
             _mod_help()
@@ -118,19 +121,49 @@ def SearchCmip6(**kwargs):
                         links.append(link)
             search.links = links
             info = search.get_info()
-        
+                
         if (rlzn != None):
             links = info.links
             all_rlzn = _realizations(links)._all_realizations()
             new_links = _get_rlzn_links(rlzn,all_rlzn,links)
             search.links=new_links
             info = search.get_info()
+            
+        if (skip!=None):
+            links = info.links
+            new_links=_get_skipped_links(links,skip)
+            search.links=new_links
+            info = search.get_info()
+        
+        if (cr!=None):
+            links = info.links
+            exps = info.exp
+            ers=[]
+            for i in range(len(exps)):
+                ers1 = [s for s in links if exps[i] in s]
+                r1 = _realizations(ers1)._all_realizations()
+                if i==1:
+                    ers2 = [s for s in links if exps[i-1] in s]
+                    r2 = _realizations(ers2)._all_realizations()
+                elif i>1:
+                    r2 = ers
+                else:
+                    ers2 = ers1
+                    r2 = _realizations(ers2)._all_realizations()
+                ers = list(set(r1) & set(r2))
+            erss=['_r'+str(s)+'i' for s in ers]
+            links=[s for s in links if any(xs in s for xs in erss)]
+            info.rlzn = ers
         
         print(color.LGREEN+"\n\n Currently available models based on your search: \n\n"+color.END,info.mod)
         print(color.LGREEN+"\nCurrently available variables based on your search: \n\n"+color.END,info.var)
         print(color.LGREEN+"\nCurrently available experiments based on your search: \n\n"+color.END,info.exp,"\n\n")
-        print(color.LGREEN+"\nNumber of files:"+color.END, info.n_files,"\n\n")
-        print(color.LGREEN+"\nAvailable realizations:"+color.END, info.rlzn,"\n\n")
+        if (cr!=None):
+            print(color.LGREEN+"\nNumber of files:"+color.END, len(links),"\n\n")
+            print(color.LGREEN+"\nAvailable common realizations:"+color.END, info.rlzn,"\n\n")
+        else:
+            print(color.LGREEN+"\nNumber of files:"+color.END, info.n_files,"\n\n")
+            print(color.LGREEN+"\nAvailable realizations:"+color.END, info.rlzn,"\n\n")
         if (_time != None):
             print(color.YELLOW+"< < < Data available for these time periods > > >\033[0m \n")
             print(info.year)
