@@ -180,7 +180,9 @@ class _Construct_urls(object):
 
         with open(str(dir_path)) as f:
             urls = f.read()
-            links = re.findall('http://.*.nc',urls)
+            links1 = re.findall('http://.*\.nc',urls)
+            links2 = re.findall('https://.*\.nc',urls)
+            links = links1 + links2
             f.close()
         if (keep==0):
             os.remove(str(dir_path))
@@ -192,7 +194,6 @@ class _realizations(object):
          self.links = links
     
     def _all_realizations(self):
-                
         er=[0]*len(self.links)
         for i in range(len(self.links)):
             try:
@@ -306,6 +307,12 @@ class _extract_info:
                          _exp.add(data[5])
                          _var.add(data[2].split('/')[(len(data[2].split('/')))-1])
                          _freq.add(data[2].split('/')[7])
+                     elif (len(data)==6):
+                        _mod.add(data[2])
+                        _realm.add(data[1])
+                        _exp.add(data[3])
+                        _var.add(data[0].split('/')[-1])
+                        _freq.add(data[1])
                      else:
                         _mod.add(data[4])
                         _realm.add(data[2].split('/')[6])
